Index: webkit/plugins/npapi/plugin_list_posix.cc |
diff --git a/webkit/plugins/npapi/plugin_list_posix.cc b/webkit/plugins/npapi/plugin_list_posix.cc |
index 175bc4ddc730a0893132f5829b0784d1f88dea32..7211e9782af8ffb1ce6254d001bb813853fe9378 100644 |
--- a/webkit/plugins/npapi/plugin_list_posix.cc |
+++ b/webkit/plugins/npapi/plugin_list_posix.cc |
@@ -216,10 +216,8 @@ void PluginList::GetPluginsInDir( |
// Java doesn't like being loaded through a symlink, since it uses |
// its path to find dependent data files. |
- // file_util::AbsolutePath calls through to realpath(), which resolves |
- // symlinks. |
- base::FilePath orig_path = path; |
- file_util::AbsolutePath(&path); |
+ // AsAbsolute calls through to realpath(), which resolves symlinks. |
+ base::FilePath orig_path = path.AsAbsolute(); |
LOG_IF(ERROR, PluginList::DebugPluginLoading()) |
<< "Resolved " << orig_path.value() << " -> " << path.value(); |